@@ -14,6 +14,8 @@ NetworkMetadataEntity = namedtuple('NetworkMetadataEntity',
 NetworkMetadataReference = namedtuple('NetworkMetadataReference',
                                       ('type', 'value', 'attributes'))
 NetworkMetadataIndex = namedtuple('NetworkMetadataIndex', ('type', 'attribute'))
+NetworkMetadataLowercaseIndex = namedtuple('NetworkMetadataLowercaseIndex',
+                                           ('type', 'attribute'))
 
 
 class NetworkMetadataClient(PreseemGrpcClient):
@@ -159,8 +161,10 @@ class PreseemNetworkMetadataModel(object):
         self._ents_lock = asyncio.Lock()
         self._refs_lock = asyncio.Lock()
         self._index = {x.type: {} for x in indexes or []}
+        self._index_cfg = {x.type: {} for x in indexes or []}
         for index in indexes or []:
             self._index[index.type][index.attribute] = {}
+            self._index_cfg[index.type][index.attribute] = index
 
     def close(self):
         self._client.close_subscriptions()
@@ -261,9 +265,13 @@ class PreseemNetworkMetadataModel(object):
                                 for n, r in (self.refs.get(it) or {}).items()
                             }
                             continue
+                        is_lower = isinstance(self._index_cfg[it][ia],
+                                              NetworkMetadataLowercaseIndex)
                         for ref in (self.refs.get(it) or {}).values():
                             attr = ref.attributes.get(ia)
                             if attr:
+                                if is_lower:
+                                    attr = attr.lower()
                                 refs = ir.get(attr)
                                 if refs is None:
                                     refs = ir[attr] = {}
@@ -300,15 +308,21 @@ class PreseemNetworkMetadataModel(object):
                                     refs = ir[None] = {}
                                 refs[ref.value.lower()] = ref
                                 continue
+                            is_lower = isinstance(self._index_cfg[ref.type][ia],
+                                                  NetworkMetadataLowercaseIndex)
                             if cur:
                                 # Remove the old ref from any indexes
                                 attr = cur.attributes.get(ia)
                                 if attr:
+                                    if is_lower:
+                                        attr = attr.lower()
                                     refs = ir.get(attr)
                                     if refs:
                                         refs.pop(ref.value, None)
                             attr = ref.attributes.get(ia)
                             if attr:
+                                if is_lower:
+                                    attr = attr.lower()
                                 refs = ir.get(attr)
                                 if refs is None:
                                     refs = ir[attr] = {}
@@ -341,6 +355,8 @@ class PreseemNetworkMetadataModel(object):
                     index = self._index.get(ref.type)
                     if index is not None:
                         for ia, ir in index.items():
+                            is_lower = isinstance(self._index_cfg[ref.type][ia],
+                                                  NetworkMetadataLowercaseIndex)
                             if ia == '_LOWER':
                                 refs = ir.get(None)
                                 if refs:
@@ -348,6 +364,8 @@ class PreseemNetworkMetadataModel(object):
                                 continue
                             attr = ref.attributes.get(ia)
                             if attr:
+                                if is_lower:
+                                    attr = attr.lower()
                                 refs = ir.get(attr)
                                 if refs:
                                     refs.pop(ref.value, None)
