@@ -503,7 +503,7 @@ async def sync_preseem_model(preseem_model,
                                            preseem_model.Element.UpdateElementDiscovery,
                                            _router_field_map,
                                            noact=noact)
-            for mobj in new_objs:
+            for mobj in router_discs + new_objs:
                 sobj = routers.get(mobj.source_id)
                 if sobj:
                     sobj._uuid = mobj.uuid
