@@ -956,6 +956,263 @@ class Error:
             setattr(self, key, value)
 
 
+class PonLink:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.NetworkElement.PonLink()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def poller_hash(self):
+        return self.pb.poller_hash
+
+    @poller_hash.setter
+    def poller_hash(self, value):
+        if value is not None:
+            self.pb.poller_hash = value
+
+    @property
+    def rx_power(self):
+        return self.pb.rx_power if self.pb.HasField('rx_power') else None
+
+    @rx_power.setter
+    def rx_power(self, value):
+        if value is not None:
+            if value >= 0 and value <= 100:
+                self.pb.rx_power = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.rx_power',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.rx_power')
+        else:
+            self.pb.ClearField('rx_power')
+
+    @property
+    def tx_power(self):
+        return self.pb.tx_power if self.pb.HasField('tx_power') else None
+
+    @tx_power.setter
+    def tx_power(self, value):
+        if value is not None:
+            if value >= 0 and value <= 100:
+                self.pb.tx_power = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.tx_power',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.tx_power')
+        else:
+            self.pb.ClearField('tx_power')
+
+    @property
+    def fiber_length(self):
+        return self.pb.fiber_length if self.pb.HasField('fiber_length') else None
+
+    @fiber_length.setter
+    def fiber_length(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.fiber_length = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.fiber_length',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.fiber_length')
+        else:
+            self.pb.ClearField('fiber_length')
+
+    @property
+    def connected_time(self):
+        return self.pb.connected_time if self.pb.HasField('connected_time') else None
+
+    @connected_time.setter
+    def connected_time(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.connected_time = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.PonLink.connected_time',
+                    value=value,
+                    metric_name='NetworkElement.PonLink.connected_time')
+        else:
+            self.pb.ClearField('connected_time')
+
+    @property
+    def rx_link_rate(self):
+        return self.pb.rx_link_rate if self.pb.HasField('rx_link_rate') else None
+
+    @rx_link_rate.setter
+    def rx_link_rate(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.rx_link_rate = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.rx_link_rate',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.rx_link_rate')
+        else:
+            self.pb.ClearField('rx_link_rate')
+
+    @property
+    def tx_link_rate(self):
+        return self.pb.tx_link_rate if self.pb.HasField('tx_link_rate') else None
+
+    @tx_link_rate.setter
+    def tx_link_rate(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.tx_link_rate = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.tx_link_rate',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.tx_link_rate')
+        else:
+            self.pb.ClearField('tx_link_rate')
+
+
+class Pon:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.NetworkElement.Pon()
+        self.errctx = errctx
+        self.links = Repeated(PonLink, self.pb.links, self.errctx)
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def id(self):
+        return self.pb.id
+
+    @id.setter
+    def id(self, value):
+        if value is not None:
+            self.pb.id = value
+
+    @property
+    def poller_hash(self):
+        return self.pb.poller_hash
+
+    @poller_hash.setter
+    def poller_hash(self, value):
+        if value is not None:
+            self.pb.poller_hash = value
+
+    @property
+    def pon_technology(self):
+        return self.pb.pon_technology if self.pb.HasField('pon_technology') else None
+
+    @pon_technology.setter
+    def pon_technology(self, value):
+        if value is not None:
+            if value > 0:
+                self.pb.pon_technology = value
+            else:  # not a valid enum value
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                "Invalid value for Networkelement.Pon.pon_technology",
+                                value=value,
+                                metric_name='NetworkElement.Pon.pon_technology')
+                self.pb.ClearField('pon_technology')
+        else:
+            self.pb.ClearField('pon_technology')
+
+    @property
+    def split_ratio(self):
+        return self.pb.split_ratio if self.pb.HasField('split_ratio') else None
+
+    @split_ratio.setter
+    def split_ratio(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.split_ratio = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Pon.split_ratio',
+                                value=value,
+                                metric_name='NetworkElement.Pon.split_ratio')
+        else:
+            self.pb.ClearField('split_ratio')
+
+    @property
+    def max_distance(self):
+        return self.pb.max_distance if self.pb.HasField('max_distance') else None
+
+    @max_distance.setter
+    def max_distance(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.max_distance = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Pon.max_distance',
+                                value=value,
+                                metric_name='NetworkElement.Pon.max_distance')
+        else:
+            self.pb.ClearField('max_distance')
+
+    @property
+    def minimum_loss(self):
+        return self.pb.minimum_loss if self.pb.HasField('minimum_loss') else None
+
+    @minimum_loss.setter
+    def minimum_loss(self, value):
+        if value is not None:
+            self.pb.minimum_loss = value
+        else:
+            self.pb.ClearField('minimum_loss')
+
+    @property
+    def maximum_loss(self):
+        return self.pb.maximum_loss if self.pb.HasField('maximum_loss') else None
+
+    @maximum_loss.setter
+    def maximum_loss(self, value):
+        if value is not None:
+            self.pb.maximum_loss = value
+        else:
+            self.pb.ClearField('maximum_loss')
+
+    @property
+    def rx_link_rate(self):
+        return self.pb.rx_link_rate if self.pb.HasField('rx_link_rate') else None
+
+    @rx_link_rate.setter
+    def rx_link_rate(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.rx_link_rate = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Pon.rx_link_rate',
+                                value=value,
+                                metric_name='NetworkElement.Pon.rx_link_rate')
+        else:
+            self.pb.ClearField('rx_link_rate')
+
+    @property
+    def tx_link_rate(self):
+        return self.pb.tx_link_rate if self.pb.HasField('tx_link_rate') else None
+
+    @tx_link_rate.setter
+    def tx_link_rate(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.tx_link_rate = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Pon.tx_link_rate',
+                                value=value,
+                                metric_name='NetworkElement.Pon.tx_link_rate')
+        else:
+            self.pb.ClearField('tx_link_rate')
+
+
 class Interface:
 
     def __init__(self, pb=None, errctx=None, **kwargs):
@@ -967,6 +1224,7 @@ class Interface:
         self.links = Repeated(Link, self.pb.links, self.errctx)
         self.radios = Repeated(Radio, self.pb.radios, self.errctx)
         self.sectors = Repeated(Sector, self.pb.sectors, self.errctx)
+        self.pons = Repeated(Pon, self.pb.pons, self.errctx)
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -1277,6 +1535,28 @@ class Interface:
         if value is not None:
             self.pb.poller_hash = value
 
+    @property
+    def manufacturer(self):
+        return self.pb.manufacturer if self.pb.HasField('manufacturer') else None
+
+    @manufacturer.setter
+    def manufacturer(self, value):
+        if value is not None:
+            self.pb.manufacturer = value
+        else:
+            self.pb.ClearField('manufacturer')
+
+    @property
+    def model(self):
+        return self.pb.model if self.pb.HasField('model') else None
+
+    @model.setter
+    def model(self, value):
+        if value is not None:
+            self.pb.model = value
+        else:
+            self.pb.ClearField('model')
+
 
 class IpMac:
 
@@ -1469,11 +1749,157 @@ class PppoeClient:
             self.pb.ClearField('mac_address')
 
 
+class Module:
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.NetworkElement.Module()
+        self.errctx = errctx
+        self.interfaces = Repeated(Interface, self.pb.interfaces, self.errctx)
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def id(self):
+        return self.pb.id
+
+    @id.setter
+    def id(self, value):
+        if value is not None:
+            self.pb.id = value
+
+    @property
+    def poller_hash(self):
+        return self.pb.poller_hash
+
+    @poller_hash.setter
+    def poller_hash(self, value):
+        if value is not None:
+            self.pb.poller_hash = value
+
+    @property
+    def name(self):
+        return self.pb.name if self.pb.HasField('name') else None
+
+    @name.setter
+    def name(self, value):
+        if value is not None:
+            self.pb.name = value
+        else:
+            self.pb.ClearField('name')
+
+    @property
+    def manufacturer(self):
+        return self.pb.manufacturer if self.pb.HasField('manufacturer') else None
+
+    @manufacturer.setter
+    def manufacturer(self, value):
+        if value is not None:
+            self.pb.manufacturer = value
+        else:
+            self.pb.ClearField('manufacturer')
+
+    @property
+    def model(self):
+        return self.pb.model if self.pb.HasField('model') else None
+
+    @model.setter
+    def model(self, value):
+        if value is not None:
+            self.pb.model = value
+        else:
+            self.pb.ClearField('model')
+
+    @property
+    def serial_number(self):
+        return self.pb.serial_number if self.pb.HasField('serial_number') else None
+
+    @serial_number.setter
+    def serial_number(self, value):
+        if value is not None:
+            self.pb.serial_number = value
+        else:
+            self.pb.ClearField('serial_number')
+
+    @property
+    def sw_version(self):
+        return self.pb.sw_version if self.pb.HasField('sw_version') else None
+
+    @sw_version.setter
+    def sw_version(self, value):
+        if value is not None:
+            self.pb.sw_version = value
+        else:
+            self.pb.ClearField('sw_version')
+
+    @property
+    def uptime(self):
+        return self.pb.uptime if self.pb.HasField('uptime') else None
+
+    @uptime.setter
+    def uptime(self, value):
+        if value is not None:
+            if value >= 0 and int.bit_length(value) < 64:
+                self.pb.uptime = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Module.uptime',
+                                value=value,
+                                metric_name='NetworkElement.Module.uptime')
+        else:
+            self.pb.ClearField('uptime')
+
+    @property
+    def cpu(self):
+        return self.pb.cpu if self.pb.HasField('cpu') else None
+
+    @cpu.setter
+    def cpu(self, value):
+        if value is not None:
+            if value >= 0 and value <= 100:
+                self.pb.cpu = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Module.cpu',
+                                value=value,
+                                metric_name='NetworkElement.Module.cpu')
+        else:
+            self.pb.ClearField('cpu')
+
+    @property
+    def mem(self):
+        return self.pb.mem if self.pb.HasField('mem') else None
+
+    @mem.setter
+    def mem(self, value):
+        if value is not None:
+            if value >= 0 and value <= 100:
+                self.pb.mem = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Module.mem',
+                                value=value,
+                                metric_name='NetworkElement.Module.mem')
+        else:
+            self.pb.ClearField('mem')
+
+    @property
+    def temperature(self):
+        return self.pb.temperature if self.pb.HasField('temperature') else None
+
+    @temperature.setter
+    def temperature(self, value):
+        if value is not None:
+            self.pb.temperature = value
+        else:
+            self.pb.ClearField('temperature')
+
+
 class NetworkElement:
 
     def __init__(self, pb=None, errctx=None, **kwargs):
         self.pb = pb if pb else network_poller_pb2.NetworkElement()
         self.errctx = errctx
+        self.modules = Repeated(Module, self.pb.modules, self.errctx)
         self.interfaces = Repeated(Interface, self.pb.interfaces, self.errctx)
         self.errors = Repeated(Error, self.pb.errors, self.errctx)
         for key, value in kwargs.items():
